@@ -22,7 +22,7 @@ data = (
 '',    # 0x14
 'N',    # 0x15
 'No. ',    # 0x16
-'',    # 0x17
+'(p)',    # 0x17
 '',    # 0x18
 'P',    # 0x19
 'Q',    # 0x1a
@@ -37,7 +37,7 @@ data = (
 '',    # 0x23
 'Z',    # 0x24
 '',    # 0x25
-'',    # 0x26
+'ohm',    # 0x26
 '',    # 0x27
 'Z',    # 0x28
 '',    # 0x29
